Package นี้เป็น Python Package แสดงข้อมูลเกี่ยวกับ Smart Home Thailand”
=======================================================================

Link: https://www.youtube.com/watch?v=JsfIcV_4eik

PyPi: https://pypi.org/project/smarthomeThailand/

สวัสดีครับ Package นี้คือ Python package ที่แสดงข้อมูลเกี่ยวกับ Smart
Home Thailand มีฟังชั่นแสดงข้อมูล DIY, Blog อธิบาย และ Youtube channel

วิธีติดตั้ง
~~~~~~~~~~~

เปิด CMD / Terminal

.. code:: python

   pip install smarthomeThailand

วิธีใช้งานแพ็คเพจนี้
~~~~~~~~~~~~~~~~~~~~

-  เปิด IDLE ขึ้นมาแล้วพิมพ์…

.. code:: python

   from smarthomeThailand import SmartHome

   smarthome = SmartHome() #ประกาศชื่อ Class
   smarthome.show_name() #Show ชื่อ
   smarthome.show_youtube() #Show link Yuotube
   smarthome.about() #Show About
   smarthome.show_art() # Show ภาพ ASCII

พัฒนาโดย: niponle FB: https://www.facebook.com/nipon.leekreingkrai

YouTube: https://www.facebook.com/nipon.leekreingkrai
